#
# spec file for package arb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           arb
%define lname   libarb2
Version:        2.23.0
Release:        2.2
Summary:        Arbitrary-precision floating-point ball arithmetic library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Scientific/Math
URL:            http://fredrikj.net/arb/
#Git-Clone:	https://github.com/fredrik-johansson/arb/
Source:         https://github.com/fredrik-johansson/arb/archive/%version.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  flint-devel >= 2.9
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  mpfr-devel
# packagers: see history.rst for changelog

%description
Arb is a C library for arbitrary-precision floating-point ball
(mid-rad interval) arithmetic. It supports complex numbers,
polynomials, matrices, and evaluation of special functions, with
error bounding.

%package -n %lname
Summary:        Arbitrary-precision floating-point ball arithmetic library
Group:          System/Libraries

%description -n %lname
Arb is a C library for arbitrary-precision floating-point ball
(mid-rad interval) arithmetic. It supports complex numbers,
polynomials, matrices, and evaluation of special functions, with
error bounding.

%package devel
Summary:        Development files for Arb, an Arbitrary-precision ball arithmetic library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Arb is a C library for arbitrary-precision floating-point ball
(mid-rad interval) arithmetic. It supports complex numbers,
polynomials, matrices, and evaluation of special functions, with
error bounding.

This subpackage contains libraries and header files for developing
applications that want to make use of Arb.

%prep
%autosetup -p1

%build
# Not autoconf
./configure --prefix="%_prefix" --disable-static CFLAGS="%optflags"
%make_build verbose

%install
%make_install LIBDIR="%_lib"

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libarb.so.2*

%files devel
%_includedir/*.h
%_libdir/libarb.so
%license LICENSE
%doc doc/source/history.rst

%changelog
* Fri Apr  7 2023 Jan Engelhardt <jengelh@inai.de>
- Explicitly switch from MPIR to GMP (due to implicit presence of
  GMP, arb was already built with it).
* Tue Jul  5 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.23.0
  * Threaded computation of Hilbert class polynomials
* Thu Apr 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.22.1
  * Much faster computation of Bernoulli numbers using hybrid
    numerical-modular algorithm.
  * Faster computation of Euler numbers using hybrid algorithm;
    added arb_fmpz_euler_number_ui.
  * Added inverse error function (arb_hypgeom_erfinv,
    arb_hypgeom_erfcinv).
  * New (faster, more accurate) implementations of real error
    functions (arb_hypgeom_erf, arb_hypgeom_erfc) and
    trigonometric integrals (arb_hypgeom_si, arb_hypgeom_ci).
  * Use arb-based printing code instead of MPFR in arf_printd and
    mag_printd so that large exponents work.
* Fri Oct 29 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.21.0
  * Experimental new arb_fpwrap module: accurate floating-point
    wrappers of Arb mathematical functions (supersedes the
    external arbcmath.h).
  * Fixed memory leak in arf_load_file.
  * New and faster gamma function code.
  * Most gamma function internals are now located in the
    arb_hypgeom and acb_hypgeom modules. The user-facing
    functions (arb_gamma, etc.) are still available under the old
    names for compatibility. The internal algorithms for rising
    factorials (binary splitting, etc.) have been moved without
    aliases.
  * Added arb_fma, arb_fma_arf, arb_fma_ui (like addmul, but take
    a separate input and output).
  * Slightly faster internal Bernoulli number generation for small n.
  * Better enclosures for acb_barnes_g at negative reals.
  * Added Graeffe transforms (arb_poly_graeffe_transform,
    acb_poly_graeffe_transform).
  * Added acb_add_error_arb.
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.19.0
  * Significant improvements to the implementation of Platt's
    algorithm for computing Riemann zeta function zeros at large
    height.
  * Better criterion for selecting asymptotic expansion of
    incomplete gamma function (contributed by p15-git-acc).
  * Multithreaded acb_dft for power-of-two lengths.
  * Added acb_csc_pi, arb_csc_pi.
  * Fixed segfault in acb_mat_eig_simple_rump when called with L
    non-NULL and R NULL.
  * Fixed bug in acb_real_abs.
  * Changed several functions to more consistently return
    infinities instead of NaNs where reasonable.
  * Added Fransen-Robinson as an integral example.
* Sun Aug 30 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.18.1
  * Faster and more accurate real matrix multiplication using
    block decomposition, scaling, and multiplying via FLINT
    integer matrices in combination with safe use of doubles for
    radius matrix multiplications.
  * New C functions for Riemann zeta function.
  * For more, see the history.rst file in the arb-devel subpackage.
* Mon Apr 30 2018 jengelh@inai.de
- Update to new upstream release 2.13.0
  * Fixed rounding direction in arb_get_abs_lbound_arf() which in
    some cases could result in an invalid lower bound being
    returned.
* Sat Feb 10 2018 jengelh@inai.de
- Update to new upstream release 2.12.0
* Wed Feb  5 2014 jengelh@inai.de
- Update to new upstream snapshot 1.0.0+git7
* Fri May 17 2013 jengelh@inai.de
- Initial package (version 0.5+git28) for build.opensuse.org
